contextFind_addin: RStudio Add-in for contextFind

View source: R/contextFind_addin.R

contextFind_addinR Documentation

RStudio Add-in for contextFind

Description

Launches an interactive gadget for searching project files. The gadget allows the user to enter a search string, choose a directory, specify whether the search should be recursive, and how many lines of context to print. Results are displayed in the console with clickable links to matched lines.

Usage

contextFind_addin()

Value

Invisibly returns the search results as a list (see contextFind()).

See Also

contextFind()


contextFind documentation built on Nov. 5, 2025, 6:04 p.m.