View source: R/contextFind_addin.R
| contextFind_addin | R Documentation |
Launches an interactive gadget for searching project files. The gadget allows the user to enter a search string, choose a directory, specify whether the search should be recursive, and how many lines of context to print. Results are displayed in the console with clickable links to matched lines.
contextFind_addin()
Invisibly returns the search results as a list (see contextFind()).
contextFind()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.